searchNodes=[{"doc":"Efficiently store and index a set of non-negative integers.A set can be constructed using IntSet.new/0:iex&gt; IntSet.new #IntSet&lt;[]&gt;An IntSet obeys the same set semantics as MapSet, and provides constant-time operations for insertion, deletion, and membership checking. Use Enum.member?/2 to check for membership.iex&gt; IntSet.new(3) |&gt; Enum.member?(3) trueSets also implement Collectable, so it can collect values in any context that a list can:iex&gt; Enum.into([1, 2, 3], IntSet.new()) #IntSet&lt;[1, 2, 3]&gt;The inspect/1 implementation for IntSet sorts the members, which makes it way easier to write doctests:iex&gt; IntSet.new([3, 1, 2]) #IntSet&lt;[1, 2, 3]&gt;Working with applications that use bitstrings becomes way easier, because IntSet.new/1 accepts a bitstring, and IntSet.bitstring/2 can return one.iex&gt; IntSet.new(5) |&gt; IntSet.bitstring() &lt;&lt;0::1, 0::1, 0::1, 0::1, 0::1, 1::1&gt;&gt; iex&gt; IntSet.new(&lt;&lt;0::1, 0::1, 0::1, 0::1, 0::1, 1::1&gt;&gt;) #IntSet&lt;[5]&gt;PerformanceAn IntSet is significantly faster than Elixir's MapSet at set operations (union, intersection, difference, equality), but slower at everything else. The case for memory usage is similar: better than MapSet for set operations, worse for everything else.OpMapSetIntSetComparisonnew4.8K2.46K1.95x slowermember?6.78M2.93M2.31x slowerput4.19M1.15M3.66x slowerunion156.4K944.31K6.04x fasterdifference48.09891.27K18.53x fasterintersection14.03K905.70K64.54x fasterequal?0.26M2.41M9.25x fasterThere is a benchmark checked into the project repo at perf/performance_test.exs. You can run it with mix run to see some results for yourself.SerializationWith the use of IntSet.bitstring/2, and IntSet.new/1, you can serialize this collection very efficiently. Remember to pass the byte_align: true option into IntSet.bitstring/2 when you do this; most encoding schemes like byte-aligned data.iex&gt; IntSet.new([4, 8, 15, 16, 23, 42]) |&gt; IntSet.bitstring(byte_align: true) |&gt; Base.encode16() &quot;088181000020&quot; iex&gt; Base.decode16!(&quot;088181000020&quot;) |&gt; IntSet.new() #IntSet&lt;[4, 8, 15, 16, 23, 42]&gt;","ref":"IntSet.html","title":"IntSet","type":"module"},{"doc":"Get a bitstring representing the members of a set.Examplesiex&gt; IntSet.new(0) |&gt; IntSet.bitstring() &lt;&lt;1::1&gt;&gt; iex&gt; IntSet.new(5) |&gt; IntSet.bitstring() &lt;&lt;0::1, 0::1, 0::1, 0::1, 0::1, 1::1&gt;&gt; iex&gt; IntSet.new() |&gt; IntSet.bitstring() &lt;&lt;&gt;&gt;You can also provide a :byte_align option, which will pad the end of the binary with zeroes until you're at a nice round n-byte size. By default this options is false.iex&gt; IntSet.new(5) |&gt; IntSet.bitstring(byte_align: true) &lt;&lt;0::1, 0::1, 0::1, 0::1, 0::1, 1::1, 0::1, 0::1&gt;&gt;","ref":"IntSet.html#bitstring/2","title":"IntSet.bitstring/2","type":"function"},{"doc":"Remove a number from the int set.Examplesiex&gt; set = IntSet.new(5) #IntSet&lt;[5]&gt; iex&gt; IntSet.delete(set, 5) #IntSet&lt;[]&gt;","ref":"IntSet.html#delete/2","title":"IntSet.delete/2","type":"function"},{"doc":"Returns a set that is int_set1 without the members of int_set2.Examplesiex&gt; IntSet.difference(IntSet.new([1, 2]), IntSet.new([2, 3, 4])) #IntSet&lt;[1]&gt;","ref":"IntSet.html#difference/2","title":"IntSet.difference/2","type":"function"},{"doc":"Checks if int_set and int_set2 have no members in common.Examplesiex&gt; IntSet.disjoint?(IntSet.new([1, 2]), IntSet.new([3, 4])) true iex&gt; IntSet.disjoint?(IntSet.new([1, 2]), IntSet.new([2, 3])) false","ref":"IntSet.html#disjoint?/2","title":"IntSet.disjoint?/2","type":"function"},{"doc":"Checks if two sets are equalExamplesiex&gt; IntSet.equal?(IntSet.new([1, 2]), IntSet.new([2, 1, 1])) true iex&gt; IntSet.equal?(IntSet.new([1, 2]), IntSet.new([3, 4])) false","ref":"IntSet.html#equal?/2","title":"IntSet.equal?/2","type":"function"},{"doc":"Find all elements that are in both int_set1 and int_set2.Examplesiex&gt; IntSet.intersection(IntSet.new([1, 2]), IntSet.new([2, 3, 4])) #IntSet&lt;[2]&gt; iex&gt; IntSet.intersection(IntSet.new([1, 2]), IntSet.new([3, 4])) #IntSet&lt;[]&gt;","ref":"IntSet.html#intersection/2","title":"IntSet.intersection/2","type":"function"},{"doc":"Returns a set of size n with all members not in the given IntSet.You can visualize this operation as calling IntSet.difference/2 with the first argument being a full IntSet of size n.Examplesiex&gt; IntSet.new(0) |&gt; IntSet.inverse(1) #IntSet&lt;[]&gt; iex&gt; IntSet.new(0) |&gt; IntSet.inverse(8) #IntSet&lt;[1, 2, 3, 4, 5, 6, 7]&gt; iex&gt; IntSet.new() |&gt; IntSet.inverse(3) #IntSet&lt;[0, 1, 2]&gt; iex&gt; IntSet.new() |&gt; IntSet.inverse(9) #IntSet&lt;[0, 1, 2, 3, 4, 5, 6, 7, 8]&gt;","ref":"IntSet.html#inverse/2","title":"IntSet.inverse/2","type":"function"},{"doc":"Create an empty int set.Examplesiex&gt; IntSet.new #IntSet&lt;[]&gt;","ref":"IntSet.html#new/0","title":"IntSet.new/0","type":"function"},{"doc":"Create an int set with some starting value.ExamplesYou can create a set with a single starting value.iex&gt; IntSet.new(0) #IntSet&lt;[0]&gt;You can also provide an enumerable of integers to start with.iex&gt; IntSet.new([1, 2, 3]) #IntSet&lt;[1, 2, 3]&gt;Lastly, you can initialize the set with a bit string. Binary strings are interpreted as little-endian, with the very first bit of the string representing the number zero.iex&gt; IntSet.new(&lt;&lt;1 :: 1&gt;&gt;) #IntSet&lt;[0]&gt; iex&gt; IntSet.new(&lt;&lt;0b1000_1000&gt;&gt;) #IntSet&lt;[0, 4]&gt; iex&gt; IntSet.new(&lt;&lt;0 :: 1&gt;&gt;) #IntSet&lt;[]&gt;","ref":"IntSet.html#new/1","title":"IntSet.new/1","type":"function"},{"doc":"Add a value to the int set.Examplesiex&gt; set = IntSet.new() #IntSet&lt;[]&gt; iex&gt; IntSet.put(set, 0) #IntSet&lt;[0]&gt;","ref":"IntSet.html#put/2","title":"IntSet.put/2","type":"function"},{"doc":"Create a new set that contains all of the elements of both x and y.Examplesiex&gt; a = IntSet.new(7) iex&gt; b = IntSet.new(4) iex&gt; IntSet.union(a, b) #IntSet&lt;[4, 7]&gt;","ref":"IntSet.html#union/2","title":"IntSet.union/2","type":"function"},{"doc":"","ref":"IntSet.html#t:t/0","title":"IntSet.t/0","type":"opaque"}]